@@ -95,7 +95,7 @@ logmsg(char *file, int line, int priority, char *msg, ...)
 		va_end(ap);
 
 		strcat(buffer, "\n");
-		fprintf(stderr, buffer);
+		fprintf(stderr, "%s", buffer);
 		fflush(stderr);
 	}
 
